@@ -11,7 +11,7 @@ import singer.schema
 from singer import utils, metadata, get_bookmark
 from singer.schema import Schema
 from singer.catalog import Catalog, CatalogEntry
-from c8connector import C8Connector, ConfigProperty
+from c8connector import C8Connector, ConfigProperty, Sample
 import c8_source_oracle.db as orc_db
 import c8_source_oracle.sync_strategies.log_miner as log_miner
 import c8_source_oracle.sync_strategies.full_table as full_table
@@ -583,12 +583,29 @@ class OracleSourceConnector(C8Connector):
       """Returns the description of the connector."""
       return "GDN data connector source for OracleDB"
 
-   def validate(self, integration: dict) -> bool:
-      """Validate given configurations against the connector."""
-      return True
+   def validate(self, integration: dict) -> None:
+      """Validate given configurations against the connector.
+      If invalid, throw an exception with the cause.
+      """
+      
+      config = {
+         'host': integration['host'],
+         'user': integration['user'],
+         'password': integration['password'],
+         'port': integration['port'],
+         'service_name': integration['service_name'],
+         'pdb_name': integration['pdb_name'],
+         'multitenant': integration['multitenant'],
+      }
+      
+      filter_schemas_prop = integration['filter_schemas']
+      filter_schemas = []
+      if filter_schemas_prop:
+         filter_schemas = filter_schemas_prop.split(',')
+      do_discovery(config, filter_schemas)
 
-   def samples(self, integration: dict) -> list:
-      """Fetch sample data using the provided configurations."""
+   def samples(self, integration: dict) -> list[Sample]:
+      """Fetch sample data using the given configurations."""
       return []
 
    def config(self) -> list[ConfigProperty]:
